==> am_mod_blg_0_1.zip: am_mod_blg_0_1/components/blg/template/barnraiser_01/blog_edit.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<script language="JavaScript" src="<?php echo $template_path_core;?>/js/imageHandling.js" type="text/javascript"></script>

<script type="text/javascript" src="speller/spellChecker.js"></script>
<script type="text/javascript">
	function openSpellChecker() {
		var speller = new spellChecker();
		speller.spellCheckAll();
	}
</script>

<form action="index.php?amn=blg_blog_edit" method="post" name="frm" id="id_frm">
<input type="hidden" name="blog_id" value="<?php if(isset($blog['blog_id'])) { echo $blog['blog_id'];}?>" />

<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_blog'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<label for="id_blog_title"><?php echo $lang['txt_title'];?></label>
					<input id="id_blog_title" class="input" type="text" name="blog_title" size="24" value="<?php if (isset($blog['blog_title'])) { echo $blog['blog_title'];}?>" />
					&nbsp;<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
					<br />
				</p>
				
				<p>
					<label for="id_blog_synopsis"><?php echo $lang['txt_synopsis'];?></label>
					<textarea id="id_blog_synopsis" name="blog_synopsis" cols="22" rows="2"><?php if (isset($blog['blog_synopsis'])) { echo $blog['blog_synopsis'];}?></textarea>
					<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
					<br />
				</p>
				
				<script type="text/javascript">
				function showMembershipTypes(id) {
					var displaystate = 'none';
					
					if (id.value == 4) {
						displaystate = 'block';
					}
					
					objShowHide('id_membership_type', displaystate);
				}
				</script>
				
				<p>
					<label for="id_blog_type"><?php echo $lang['txt_participation'];?></label><?php
					// if this is set to membership type and we do not have permission to change this
					// we just print out that
					if (isset($blog['blog_type']) && $blog['blog_type'] == $blog_config['type']['membership_type'] && $_SESSION['user_core_permission'] ^ $core_config['resource']['user']['mem_visible']) {
						echo $lang['blog_type'][$blog['blog_type']];
						if (!empty($blog['membership_type_ids'])) {
							$prnt = "<br /><i>(";
							foreach ($set['membership_type_ids'] as $keymt => $mt):
								$prnt .= $lang['membership_type'][$mt['membership_type_id']] . ", ";
							endforeach;

							$prnt = substr ($prnt, 0, -2) . ")</i><br />";
							echo $prnt;
						}
					}
					else {
					?>
					<select id="id_blog_type" name="blog_type" style="width:160px;" onChange="javascript:showMembershipTypes(this);">
						<?php
						if (isset($blog_config['type'])) {
						foreach ($blog_config['type'] as $key => $i):

						// check to see if we are allowed to set membership types
						if ($i == $blog_config['type']['membership_type'] && $_SESSION['user_core_permission'] ^ $core_config['resource']['user']['mem_visible']) {
							break;
						}

						$selected = "";
						if (isset($blog['blog_type']) && $blog['blog_type'] == $key) {
							$selected = "selected=\"selected\"";
						}
						
						?>
						<option value="<?php echo $i;?>" <?php echo $selected;?>><?php echo $lang['blog_type'][$i];?></option>
						<?php
						endforeach;
						}
						?>
					</select>
					<?php }?>
				</p>
				
				<?php
				if ($_SESSION['user_core_permission'] & $core_config['resource']['user']['mem_visible']) {
				?>
				<p id="id_membership_type">
					<?php
					if (isset($lang['membership_type'])) {
					foreach ($lang['membership_type'] as $key => $i):
						
					$selected = "";
					
					if (!empty($blog['membership_type_ids'])) {					
						foreach ($blog['membership_type_ids'] as $keymt => $mt):
							if ($mt['membership_type_id'] == $key) {
								$selected = "checked=\"checked\"";
								break;
							}
						endforeach;
					}
					?>
					<label></label>
					<input type="checkbox" name="membership_types[]" value="<?php echo $key;?>" <?php echo $selected;?> />&nbsp;<?php echo $i;?><br />
					<?php
					endforeach;
					}
					?>
				</p>
				
				<script type="text/javascript">
					var id = document.getElementById('id_blog_type');
					showMembershipTypes(id);
				</script>
				<?php }?>
				
				
				<?php if (!isset($blog['blog_id'])) { ?>
					<label for="identity_id"><?php echo $lang['txt_my_identity']; ?></label>
					<select name="identity_id">
						<?php foreach($identities as $i): ?>
							<?php 
								$selected = '';
								if (!empty($_REQUEST['identity_id'])) {
									if ($i['identity_id'] == $_REQUEST['identity_id']) {
										$selected = "selected=\"selected\"";
									}
								}
							?>
							<option value="<?php echo $i['identity_id']; ?>" <?php echo $selected; ?>><?php echo $i['identity_name']; ?></option>
						<?php endforeach; ?>
					</select>
				<?php  } ?>
					
				<?php
				if (isset($images)) {
				?>
				<table cellspacing="0" cellpadding="2" border="0" width="100%">
					<tr>
						<td valign="top">
							<label for="frm_file" style="width:105px;"><?php echo $lang['txt_image']; ?></label><br />	
						</td>
						<td valign="top" width="100%">
							<select style="width:150px;" id="id_file_id" size=3 name="file_id" onChange='javascript:setimg(this)'>
								<option value="0" selected="selected"><?php echo $lang['txt_none'];?></option>
								<?php
								$img_divs = "";
								foreach($images as $key => $i):
								$display_state = "none";
								$selected = "";
								if (isset($blog['file_id']) && $blog['file_id'] == $i['file_id']) {
									$selected = "selected=\"selected\"";
									$display_state = "block";
								}
								?>
								<option value="<?php echo $i['file_id'];?>" <?php echo $selected;?>><?php echo $i['file_save_name'];?></option>
								<?php
								$img_divs .= "<div style=\"display:" . $display_state . ";\" id=img" . $i['file_id'] . "><img src=\"get_file.php?file=" . $i['file_md5_name_view'] . "&amp;type=" . $i['file_type'] . "&amp;directory=" . $i['directory'] . "\" border=\"0\" class=\"picture\" /></div>";
								endforeach;
								?>
							</select>
						</td>
						<td valign="top" align="right">
							<?php echo $img_divs;?>
						</td>	
					</tr>
				</table>
				<?php }?>
				
				<p>
					<label for="id_blog_level"><?php echo $lang['txt_publish'];?></label>
					<select id="id_blog_level" name="level_id" style="width:160px;">
						<?php
						if (isset($lang['blog_level'])) {
						foreach ($lang['blog_level'] as $key => $i):
						
						$selected = "";
						if (isset($blog['level_id']) && $blog['level_id'] == $key) {
							$selected = "selected=\"selected\"";
						}
						?>
						<option value="<?php echo $key;?>" <?php echo $selected;?>><?php echo $i;?></option>
						<?php
						endforeach;
						}
						?>
					</select>
				</p>
						
		
				<?php
				if (count($lang['arr_lang_name']) > 1) {
				?>
				<p>
					<label for="id_languages"><?php echo $lang['txt_language'];?></label>
					<select name="language_id">
					<?php 
					foreach($lang['arr_lang_name'] as $key => $i): 
					?>
						<option value="<?php echo $key;?>" <?php if(isset($blog) && $blog['language_id'] == $key) echo "selected=\"selected\"";?>><?php echo ucFirst($lang['arr_lang_name'][$key]);?></option>
					<?php
					endforeach;
					?>
					</select>
				</p>
				<?php }?>
				
				<?php
				if (isset($blog) && !empty($lang['blog_status'])) {
				?>
				<p>
					<label for="id_status"><?php echo $lang['txt_status'];?></label>
					<select name="status_id">
						<?php foreach($lang['blog_status'] as $key => $i): 
						if (isset($lang['blog_status'][$key])) {
					
						?>
						<option value="<?php echo $key;?>" <?php if(isset($blog) && $blog['status_id'] == $i) { echo "selected=\"selected\"";}?>><?php echo $lang['blog_status'][$key];?></option>
						<?php 
						}
						endforeach;
						?>
					</select>
				</p>
				<?php }?>
				
				<?php
				if (isset($blog_config['resource']['blog'])) {
				?>
				
				<hr />
				
				<p>
					<b><?php echo $lang['hdr_permissions'];?></b><br />
				</p>
		
				<?php
				foreach($blog_config['resource']['blog'] as $rekey => $re):
				?>
				
				<?php
				$checked = "";
				if (isset($blog)) {
					if ($blog['blog_permission'] & $blog_config['resource']['blog'][$rekey]) {
						$checked = "checked=\"checked\"";
					}
				}
				?>
				<p>
					<input type="checkbox" name="permission[blog][<?php echo $re;?>]" value="<?php echo $re;?>" <?php echo $checked;?> />&nbsp;
					<?php echo $lang['resource'][$module_prefix]['blog'][$re];?><br />
				</p>
				<?php
				endforeach;
				?>		
				<?php }?>
				
				
				<hr />
							
				<p align="right">
					<?php
					if (isset($allow_spellcheck)) {
					?>
					<input type="button" class="input_submit" value="<?php echo $lang['sub_check_spelling'];?>" onClick="openSpellChecker();" />
					<?php }?>
					
					<input type="submit" name="save_blog" class="input_submit" value="<?php echo $lang['sub_update'];?>" />
					<br />
				</p>
			</div>
		</div>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_starting_a_blog'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<?php echo $lang['txt_blog_create_intro'];?><br />
				</p>
			</div>
		</div>
	</div>
</div>			
</form>

==> am_mod_blg_0_3.zip: am_mod_blg_0_3/components/blg/template/barnraiser_01/blog_edit.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<script language="JavaScript" src="<?php echo $template_path_core;?>/js/imageHandling.js" type="text/javascript"></script>

<script type="text/javascript" src="speller/spellChecker.js"></script>
<script type="text/javascript">
	function openSpellChecker() {
		var speller = new spellChecker();
		speller.spellCheckAll();
	}
</script>

<form action="index.php?amn=blg_blog_edit" method="post" name="frm" id="id_frm">
<input type="hidden" name="blog_id" value="<?php if(isset($blog['blog_id'])) { echo $blog['blog_id'];}?>" />

<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_blog'];?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<label for="id_blog_title"><?php echo $lang['txt_title'];?></label>
					<input id="id_blog_title" class="input" type="text" name="blog_title" size="24" value="<?php if (isset($blog['blog_title'])) { echo $blog['blog_title'];}?>" />
					&nbsp;<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
					<br />
				</p>
				
				<p>
					<label for="id_blog_synopsis"><?php echo $lang['txt_synopsis'];?></label>
					<textarea id="id_blog_synopsis" name="blog_synopsis" cols="22" rows="2"><?php if (isset($blog['blog_synopsis'])) { echo $blog['blog_synopsis'];}?></textarea>
					<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
					<br />
				</p>
				
				<script type="text/javascript">
				function showMembershipTypes(id) {
					var displaystate = 'none';
					
					if (id.value == 4) {
						displaystate = 'block';
					}
					
					objShowHide('id_membership_type', displaystate);
				}
				</script>
				
				<p>
					<label for="id_blog_type"><?php echo $lang['txt_participation'];?></label><?php
					// if this is set to membership type and we do not have permission to change this
					// we just print out that
					if (isset($blog['blog_type']) && $blog['blog_type'] == $blog_config['type']['membership_type'] && $core_config['resource']['user']['mem_visible'] & ~$_SESSION['user_core_permission']) {
						echo $lang['blog_type'][$blog['blog_type']];
						if (!empty($blog['membership_type_ids'])) {
							$prnt = "<br /><i>(";
							foreach ($set['membership_type_ids'] as $keymt => $mt):
								$prnt .= $lang['membership_type'][$mt['membership_type_id']] . ", ";
							endforeach;

							$prnt = substr ($prnt, 0, -2) . ")</i><br />";
							echo $prnt;
						}
					}
					else {
					?>
					<select id="id_blog_type" name="blog_type" style="width:160px;" onChange="javascript:showMembershipTypes(this);">
						<?php
						if (isset($blog_config['type'])) {
						foreach ($blog_config['type'] as $key => $i):

						// check to see if we are allowed to set membership types
						if ($i == $blog_config['type']['membership_type'] && $core_config['resource']['user']['mem_visible'] & ~$_SESSION['user_core_permission']) {
							break;
						}

						$selected = "";
						if (isset($blog['blog_type']) && $blog['blog_type'] == $i) {
							$selected = "selected=\"selected\"";
						}
						
						?>
						<option value="<?php echo $i;?>" <?php echo $selected;?>><?php echo $lang['blog_type'][$i];?></option>
						<?php
						endforeach;
						}
						?>
					</select>
					<?php }?>
				</p>
				
				<?php
				if ($_SESSION['user_core_permission'] & $core_config['resource']['user']['mem_visible']) {
				?>
				<p id="id_membership_type">
					<?php
					if (isset($lang['membership_type'])) {
					foreach ($lang['membership_type'] as $key => $i):
						
					$selected = "";
					
					if (!empty($blog['membership_type_ids'])) {					
						foreach ($blog['membership_type_ids'] as $keymt => $mt):
							if ($mt['membership_type_id'] == $key) {
								$selected = "checked=\"checked\"";
								break;
							}
						endforeach;
					}
					?>
					<label></label>
					<input type="checkbox" name="membership_types[]" value="<?php echo $key;?>" <?php echo $selected;?> />&nbsp;<?php echo $i;?><br />
					<?php
					endforeach;
					}
					?>
				</p>
				
				<script type="text/javascript">
					var id = document.getElementById('id_blog_type');
					showMembershipTypes(id);
				</script>
				<?php }?>
				
				
				<?php if (!isset($blog['blog_id'])) { ?>
					<label for="identity_id"><?php echo $lang['txt_my_identity']; ?></label>
					<select name="identity_id">
						<?php foreach($identities as $i): ?>
							<?php 
								$selected = '';
								if (!empty($_REQUEST['identity_id'])) {
									if ($i['identity_id'] == $_REQUEST['identity_id']) {
										$selected = "selected=\"selected\"";
									}
								}
							?>
							<option value="<?php echo $i['identity_id']; ?>" <?php echo $selected; ?>><?php echo $i['identity_name']; ?></option>
						<?php endforeach; ?>
					</select>
				<?php  } ?>
					
				<?php
				if (isset($images)) {
				?>
				<table cellspacing="0" cellpadding="2" border="0" width="100%">
					<tr>
						<td valign="top">
							<label for="frm_file" style="width:105px;"><?php echo $lang['txt_image']; ?></label><br />	
						</td>
						<td valign="top" width="100%">
							<select style="width:150px;" id="id_file_id" size=3 name="file_id" onChange='javascript:setimg(this)'>
								<option value="0" selected="selected"><?php echo $lang['txt_none'];?></option>
								<?php
								$img_divs = "";
								foreach($images as $key => $i):
								$display_state = "none";
								$selected = "";
								if (isset($blog['file_id']) && $blog['file_id'] == $i['file_id']) {
									$selected = "selected=\"selected\"";
									$display_state = "block";
								}
								?>
								<option value="<?php echo $i['file_id'];?>" <?php echo $selected;?>><?php echo $i['file_save_name'];?></option>
								<?php
								$img_divs .= "<div style=\"display:" . $display_state . ";\" id=img" . $i['file_id'] . "><img src=\"get_file.php?file=" . $i['file_md5_name_view'] . "&amp;type=" . $i['file_type'] . "&amp;directory=" . $i['directory'] . "\" border=\"0\" class=\"picture\" /></div>";
								endforeach;
								?>
							</select>
						</td>
						<td valign="top" align="right">
							<?php echo $img_divs;?>
						</td>	
					</tr>
				</table>
				<?php }?>
				
				<p>
					<label for="id_blog_level"><?php echo $lang['txt_publish'];?></label>
					<select id="id_blog_level" name="level_id" style="width:160px;">
						<?php
						if (isset($lang['blog_level'])) {
						foreach ($lang['blog_level'] as $key => $i):
						
						$selected = "";
						if (isset($blog['level_id']) && $blog['level_id'] == $key) {
							$selected = "selected=\"selected\"";
						}
						?>
						<option value="<?php echo $key;?>" <?php echo $selected;?>><?php echo $i;?></option>
						<?php
						endforeach;
						}
						?>
					</select>
				</p>
						
		
				<?php
				if (count($lang['arr_lang_name']) > 1) {
				?>
				<p>
					<label for="id_languages"><?php echo $lang['txt_language'];?></label>
					<select name="language_id">
					<?php 
					foreach($lang['arr_lang_name'] as $key => $i): 
					?>
						<option value="<?php echo $key;?>" <?php if(isset($blog) && $blog['language_id'] == $key) echo "selected=\"selected\"";?>><?php echo ucFirst($lang['arr_lang_name'][$key]);?></option>
					<?php
					endforeach;
					?>
					</select>
				</p>
				<?php }?>
				
				<?php
				if (isset($blog) && !empty($lang['blog_status'])) {
				?>
				<p>
					<label for="id_status"><?php echo $lang['txt_status'];?></label>
					<select name="status_id">
						<?php foreach($lang['blog_status'] as $key => $i): 
						if (isset($lang['blog_status'][$key])) {
					
						?>
						<option value="<?php echo $key;?>" <?php if(isset($blog) && $blog['status_id'] == $i) { echo "selected=\"selected\"";}?>><?php echo $lang['blog_status'][$key];?></option>
						<?php 
						}
						endforeach;
						?>
					</select>
				</p>
				<?php }?>
				
				<?php
				if (isset($blog_config['resource']['blog'])) {
				?>
				
				<hr />
				
				<p>
					<b><?php echo $lang['hdr_permissions'];?></b><br />
				</p>
		
				<?php
				foreach($blog_config['resource']['blog'] as $rekey => $re):
				?>
				
				<?php
				$checked = "";
				if (isset($blog)) {
					if ($blog['blog_permission'] & $blog_config['resource']['blog'][$rekey]) {
						$checked = "checked=\"checked\"";
					}
				}
				?>
				<p>
					<input type="checkbox" name="permission[blog][<?php echo $re;?>]" value="<?php echo $re;?>" <?php echo $checked;?> />&nbsp;
					<?php echo $lang['resource'][$module_prefix]['blog'][$re];?><br />
				</p>
				<?php
				endforeach;
				?>		
				<?php }?>
				
				
				<hr />
							
				<p align="right">
					<?php
					if (isset($allow_spellcheck)) {
					?>
					<input type="button" class="input_submit" value="<?php echo $lang['sub_check_spelling'];?>" onClick="openSpellChecker();" />
					<?php }?>
					
					<input type="submit" name="save_blog" class="input_submit" value="<?php echo $lang['sub_update'];?>" />
					<br />
				</p>
			</div>
		</div>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<h1><?php echo $lang['hdr_starting_a_blog'];?></h1>
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<?php echo $lang['txt_blog_create_intro'];?><br />
				</p>
			</div>
		</div>
	</div>
</div>
</form>
